<?php

namespace App\Http\Controllers\Admin\Settings;

use App\Contracts\Repositories\BusinessSettingRepositoryInterface;
use App\Enums\ViewPaths\Admin\BusinessSettings;
use App\Http\Controllers\BaseController;
use Brian2694\Toastr\Facades\Toastr;
use Illuminate\Contracts\View\View;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;

class DeliverymanSettingsController extends BaseController
{

    public function __construct(
        private readonly BusinessSettingRepositoryInterface $businessSettingRepo,
    )
    {
    }

    /**
     * @param Request|null $request
     * @param string|null $type
     * @return View Index function is the starting point of a controller
     * Index function is the starting point of a controller
     */
    public function index(Request|null $request, string $type = null): View
    {
        return $this->getView();
    }

    public function getView(): View
    {
        $data = $this->businessSettingRepo->getFirstWhere(params: ['type' => 'upload_picture_on_delivery']);
        return view(BusinessSettings::DELIVERYMAN_VIEW[VIEW], compact('data'));
    }

    public function update(Request $request): RedirectResponse
    {
        $this->businessSettingRepo->updateOrInsert(type: 'upload_picture_on_delivery', value: $request->get('upload_picture_on_delivery', 0));
        $this->businessSettingRepo->updateOrInsert(type: 'deliveryman_forgot_password_method', value: $request->get('deliveryman_forgot_password_method', 'phone'));
        clearWebConfigCacheKeys();
        Toastr::success(translate('Updated_successfully'));
        return redirect()->back();
    }

}
